
DROP TABLE tratamientos;
DROP TABLE diagnosticos;
DROP TABLE sintomas;
DROP TABLE resultados;
DROP TABLE pruebas;
DROP TABLE casos;

/*==============================================================*/
/* Table: Casos                                                 */
/*==============================================================*/
CREATE TABLE casos (
  idCaso				INT NOT NULL,
  nombre				VARCHAR(MAX) NOT NULL,
  descripcion   TEXT NOT NULL,
  categoria     VARCHAR(MAX) NOT NULL DEFAULT 'Ninguna',
  PRIMARY KEY(idCaso)
);


/*==============================================================*/
/* Table: Sintomas                                              */
/*==============================================================*/
CREATE TABLE sintomas (
  idSintoma			INT NOT NULL,
  nombre				VARCHAR(MAX) NOT NULL,
  descripcion   TEXT NOT NULL,
  idCaso				INT NOT NULL,
  PRIMARY KEY(idSintoma),
  CONSTRAINT FK_sc_caso FOREIGN KEY(idCaso)
    REFERENCES casos (idCaso)
    ON DELETE CASCADE
    ON UPDATE CASCADE
);


/*==============================================================*/
/* Table: Pruebas                                               */
/*==============================================================*/
CREATE TABLE pruebas (
  idPrueba			INT NOT NULL,
  nombre				VARCHAR(MAX) NOT NULL,
  descripcion   TEXT NOT NULL,
  correcta      INT NOT NULL DEFAULT 1,
  idCaso				INT NOT NULL,
  PRIMARY KEY(idPrueba),
  CONSTRAINT FK_pc_caso FOREIGN KEY(idCaso)
    REFERENCES casos (idCaso)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CHECK (correcta IN (0, 1))
);


/*==============================================================*/
/* Table: Resultados                                            */
/*==============================================================*/
CREATE TABLE resultados (
  idResultado		INT NOT NULL,
  nombre				VARCHAR(MAX) NOT NULL,
  descripcion		TEXT NOT NULL,
  idPrueba 			INT NOT NULL,
  PRIMARY KEY(idResultado),
  CONSTRAINT FK_rp_prueba FOREIGN KEY(idPrueba)
  	REFERENCES pruebas (idPrueba)
    ON DELETE CASCADE
    ON UPDATE CASCADE
);


/*==============================================================*/
/* Table: Diagnosticos                                          */
/*==============================================================*/
CREATE TABLE diagnosticos (
  idDiagnostico		INT NOT NULL,
  nombre					VARCHAR(MAX) NOT NULL,
  descripcion   	TEXT NOT NULL,
  correcto 				INT NOT NULL DEFAULT 1,
  idCaso					INT NOT NULL,
  PRIMARY KEY(idDiagnostico),
  CONSTRAINT FK_dc_caso FOREIGN KEY(idCaso)
    REFERENCES casos (idCaso)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CHECK (correcto IN (0, 1))  
);


/*==============================================================*/
/* Table: Tratamientos                                          */
/*==============================================================*/
CREATE TABLE tratamientos (
  idTratamiento		INT NOT NULL,
  nombre					VARCHAR(MAX) NOT NULL,
  descripcion   	TEXT NOT NULL,
  correcto 				INT NOT NULL DEFAULT 1,
  idCaso					INT NOT NULL,
  PRIMARY KEY(idTratamiento),
  CONSTRAINT FK_tc_caso FOREIGN KEY(idCaso)
    REFERENCES casos (idCaso)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CHECK (correcto IN (0, 1))
);
